import causalchamber.datasets
import causalchamber.utils
import causalchamber.ground_truth

citation = """
@article{gamella2024chamber,
  title={The Causal Chambers: Real Physical Systems as a Testbed for AI Methodology},
  author={Gamella, Juan L. and B\"uhlmann, Peter and Peters, Jonas},
  journal={arXiv preprint arXiv:TODO},
  year={2024}
}
"""

print(
    f"If you use our datasets or models for your work please consider citing:\n{citation}"
)
